@@ -287,29 +287,6 @@ class Network:
         self._agent_type_size = agent_type_size
         self._demand_period_size = demand_period_size
 
-    @staticmethod
-    def convert_allowed_use(au):
-        if au.lower().startswith('auto'):
-            return 'p'
-        elif au.lower().startswith('bike'):
-            return 'b'
-        elif au.lower().startswith('walk'):
-            return 'w'
-        elif au.lower().startswith('all'):
-            return 'a'
-        else:
-            raise Exception('allowed use type is not in the predefined list!')
-
-    def _setup_allowed_use(self, allowed_uses):
-        for i, link in enumerate(self.link_list):
-            modes = link.allowed_uses.split(',')
-            if not modes:
-                continue
-
-            allowed_uses[i] = ''.join(
-                Network.convert_allowed_use(m) for m in modes
-            )
-
     def allocate_for_CAPI(self):
         # execute only on the first call
         if self.has_capi_allocated:
@@ -438,7 +415,7 @@ class Network:
         #     agent.agent_seq_no = i
 
         self.agent_size = len(self.agent_list)
-        print(f"the number of agents is {self.agent_size}")
+        print(f'the number of agents is {self.agent_size}')
 
     def _get_agent(self, agent_no):
         """ retrieve agent using agent_no """
@@ -871,7 +848,7 @@ class SPNetwork(Network):
         try:
             return self.node_id_to_no[node_id]
         except KeyError:
-            raise(f"EXCEPTION: Node ID {node_id} NOT IN THE NETWORK!!")
+            raise(f'EXCEPTION: Node ID {node_id} NOT IN THE NETWORK!!')
 
     def get_agent_type(self):
         return self.agent_type
@@ -948,7 +925,6 @@ class SPNetwork(Network):
 
 class AccessNetwork(Network):
     """ network for accessibility evaluation """
-
     def __init__(self, base, add_cc=True):
         self.base = base
         self.node_list = self.base.get_nodes()
@@ -1052,7 +1028,6 @@ class AccessNetwork(Network):
         ----------
         mode : agent name which is in settings.yml.
         """
-        # assert(mode in ['p', 'w', 'b', 'a'])
         self.agent_type_name = mode
 
     def set_source_node_id(self, node_id):
@@ -1143,7 +1118,7 @@ class AccessNetwork(Network):
                 self.link_cost_array[link.get_seq_no()] = (
                     link.get_period_fftt(demand_period_id)
                     + link.get_route_choice_cost()
-                    + link.get_toll() / min(SMALL_DIVISOR, vot) * 60
+                    + link.get_toll() / max(SMALL_DIVISOR, vot) * 60
                 )
         else:
             if at.get_type_str().startswith('p'):
@@ -1151,7 +1126,7 @@ class AccessNetwork(Network):
                     self.link_cost_array[link.get_seq_no()] = (
                         link.get_free_flow_travel_time()
                         + link.get_route_choice_cost()
-                        + link.get_toll() / min(SMALL_DIVISOR, vot) * 60
+                        + link.get_toll() / max(SMALL_DIVISOR, vot) * 60
                     )
             else:
                 ffs = at.get_free_flow_speed()
@@ -1160,7 +1135,7 @@ class AccessNetwork(Network):
                     self.link_cost_array[link.get_seq_no()] = (
                         (link.get_length() / max(SMALL_DIVISOR, ffs) * 60)
                         + link.get_route_choice_cost()
-                        + link.get_toll() / min(SMALL_DIVISOR, vot) * 60
+                        + link.get_toll() / max(SMALL_DIVISOR, vot) * 60
                     )
 
 
@@ -1403,7 +1378,7 @@ class Assignment:
     def get_accessible_nodes(self, source_node_id, time_budget,
                              mode, time_dependent, tau):
         if source_node_id not in self.network.node_id_to_no_dict.keys():
-            raise Exception(f"Node ID: {source_node_id} not in the network")
+            raise Exception(f'Node ID: {source_node_id} not in the network')
 
         assert(time_budget>=0)
 
